Application actor for Simplex BFT consensus.
This module provides the application layer that interfaces between the Simplex consensus engine and the Guts application logic.
Structs
- Actor
- Application actor that handles consensus callbacks.
- Config
- Configuration for the application actor.
- Mailbox
- Mailbox for the application actor.
Enums
- Message
- Messages sent to the application.
Type Aliases
- Finalized
Callback - Type alias for the finalization callback.