SimplexBlock

Struct SimplexBlock 

pub struct SimplexBlock {
    pub parent: Digest,
    pub height: u64,
    pub timestamp: u64,
    pub state_root: [u8; 32],
    pub tx_count: u32,
    pub tx_root: [u8; 32],
    /* private fields */
}
A block in the Simplex consensus chain.

This block type is designed for the Guts decentralized code collaboration platform and follows the Simplex BFT consensus protocol.

Fields

parent: Digest

The parent block’s digest.

height: u64

The height of the block in the blockchain.

timestamp: u64

The timestamp of the block (in milliseconds since the Unix epoch).

state_root: [u8; 32]

State root after applying transactions in this block.

tx_count: u32

Number of transactions in this block.

tx_root: [u8; 32]

Serialized transaction data (for lightweight blocks, actual data synced separately).

Implementations

Source

impl SimplexBlock

pub fn new( parent: Digest, height: u64, timestamp: u64, state_root: [u8; 32], tx_count: u32, tx_root: [u8; 32], ) -> Self

Creates a new block.

pub fn genesis() -> Self

Creates a genesis block.