pub struct VoteCollector { /* private fields */ }Expand description
Vote collection for tracking quorum.
Implementations
Sourceimpl VoteCollector
impl VoteCollector
Sourcepub fn add_notarize(&mut self, vote: NotarizeMessage)
pub fn add_notarize(&mut self, vote: NotarizeMessage)
Adds a notarize vote.
Sourcepub fn add_finalize(&mut self, vote: FinalizeMessage)
pub fn add_finalize(&mut self, vote: FinalizeMessage)
Adds a finalize vote.
Sourcepub fn add_nullify(&mut self, vote: NullifyMessage)
pub fn add_nullify(&mut self, vote: NullifyMessage)
Adds a nullify vote.
Sourcepub fn get_notarize_votes(&self, block_id: &BlockId) -> &[NotarizeMessage]
pub fn get_notarize_votes(&self, block_id: &BlockId) -> &[NotarizeMessage]
Gets notarize votes for a block.
Sourcepub fn get_finalize_votes(&self, block_id: &BlockId) -> &[FinalizeMessage]
pub fn get_finalize_votes(&self, block_id: &BlockId) -> &[FinalizeMessage]
Gets finalize votes for a block.
Sourcepub fn get_nullify_votes(&self, view: u64) -> &[NullifyMessage]
pub fn get_nullify_votes(&self, view: u64) -> &[NullifyMessage]
Gets nullify votes for a view.
Sourcepub fn notarize_count(&self, block_id: &BlockId) -> usize
pub fn notarize_count(&self, block_id: &BlockId) -> usize
Returns the number of notarize votes for a block.
Sourcepub fn finalize_count(&self, block_id: &BlockId) -> usize
pub fn finalize_count(&self, block_id: &BlockId) -> usize
Returns the number of finalize votes for a block.
Sourcepub fn nullify_count(&self, view: u64) -> usize
pub fn nullify_count(&self, view: u64) -> usize
Returns the number of nullify votes for a view.
Sourcepub fn clear_view(&mut self, view: u64)
pub fn clear_view(&mut self, view: u64)
Clears votes for a given view (after finalization or nullification).